import 'package:meta/meta.dart';
import 'package:zhiying_base_widget/pages/feedback_page/model/feedback_record_data_model.dart';
import 'package:zhiying_base_widget/pages/feedback_page/model/feedback_record_style_model.dart';

@immutable
abstract class FeedbackRecordState {}

class FeedbackRecordInitial extends FeedbackRecordState {}

/// 数据加载成功
class FeedbackRecordLoadedState extends FeedbackRecordState {
  FeedbackRecordDataModel dataModel;
  FeedbackRecordStyleModel styleModel;

  FeedbackRecordLoadedState({this.dataModel, this.styleModel});
}

/// 初始化失败
class FeedbackRecordInitErrorState extends FeedbackRecordState{}

/// 刷新成功与失败
class FeedbackRecordRefreshSuccessState extends FeedbackRecordState{}
class FeedbackRecordRefreshErrorState extends FeedbackRecordState{}
/// 加载更多成功与失败
class FeedbackRecordLoadSuccessState extends FeedbackRecordState{}
class FeedbackRecordLoadErrorState extends FeedbackRecordState{}
